@@ -18,15 +18,21 @@
 #ifndef __VOTCA_CSG_XYZREADER_H
 #define __VOTCA_CSG_XYZREADER_H
 
+// Standard includes
 #include <fstream>
 #include <iostream>
 #include <string>
-#include <votca/csg/topologyreader.h>
-#include <votca/csg/trajectoryreader.h>
+#include <type_traits>
+
+// VOTCA includes
 #include <votca/tools/constants.h>
 #include <votca/tools/getline.h>
+#include <votca/tools/unitconverter.h>
+
+// Local VOTCA includes
+#include "topologyreader.h"
+#include "trajectoryreader.h"
 
-#include <type_traits>
 namespace votca {
 namespace csg {
 
@@ -39,6 +45,8 @@ namespace csg {
 */
 class XYZReader : public TrajectoryReader, public TopologyReader {
  public:
+  const tools::DistanceUnit distance_unit = tools::DistanceUnit::angstroms;
+
   XYZReader() = default;
   ~XYZReader() override = default;
 
