@@ -32,7 +32,7 @@ Allowed options:
                               default: exponential(non-bonded), linear (bonded)
     --rfct FCT                type of the right extrapolation function
                               possible: ${fct_types}
-                              default: constant(non-bonded), linear (bonded)
+                              default: constant(non-bonded), periodic(dihedral), linear (bonded)
     --avg-points INT          number of average points
                               default: $avg_points
 
@@ -88,11 +88,14 @@ echo "Extrapolate $input to $output"
 
 intermediate="$(critical mktemp "${input}.onlyleft.XXXXX")"
 if [[ $pot_type = "non-bonded"  ]]; then
-  do_external table extrapolate --function ${lfct:-exponential} --avgpoints $avg_points --region left "${input}" "${intermediate}"
-  do_external table extrapolate --function ${rfct:-constant} --avgpoints 1 --region right "${intermediate}" "${output}"
-elif [[ $pot_type = "bond"  || $pot_type = "angle" || $pot_type = "dihedral" ]]; then
-  do_external table extrapolate --function ${lfct:-linear} --avgpoints $avg_points --region left "${input}" "${intermediate}"
-  do_external table extrapolate --function ${rfct:-linear} --avgpoints $avg_points --region right "${intermediate}" "${output}"
+  do_external table extrapolate --function "${lfct:-exponential}" --avgpoints "$avg_points" --region left "${input}" "${intermediate}"
+  do_external table extrapolate --function "${rfct:-constant}" --avgpoints 1 --region right "${intermediate}" "${output}"
+elif [[ $pot_type = "bond"  || $pot_type = "angle" ]]; then
+  do_external table extrapolate --function "${lfct:-linear}" --avgpoints "$avg_points" --region left "${input}" "${intermediate}"
+  do_external table extrapolate --function "${rfct:-linear}" --avgpoints "$avg_points" --region right "${intermediate}" "${output}"
+elif [[ $pot_type = "dihedral" ]]; then
+  do_external table extrapolate --function "${lfct:-linear}" --avgpoints "$avg_points" --region left "${input}" "${intermediate}"
+  do_external table extrapolate --function "${rfct:-periodic}" --avgpoints "$avg_points" --region right "${intermediate}" "${output}"
 else
   die "${0##*/}: I don't know how to extraploate potential type '$pot_type', go and implement it!"
 fi
