@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# Copyright 2009-2013 The VOTCA Development Team (http://www.votca.org)
+# Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -75,7 +75,8 @@ done
 
 [[ -z $1 || -z $2 ]] && die "${0##*/}: missing argument"
 input="$1"
-trunc="${1%%.*}"
+trunc=${1##*/}
+trunc="${trunc%%.*}"
 [[ -f $input ]] || die "${0##*/}: Could not find input file '$input'"
 output="$2"
 echo "Convert $input to $output"
@@ -91,7 +92,7 @@ if [[ $tabtype = "non-bonded" ]]; then
   if [[ -f ${mdp} ]]; then
     echo "Found setting file '$mdp' now trying to check options in there"
     rlist=$(get_simulation_setting rlist)
-    tabext=$(get_simulation_setting table-extension)
+    tabext=$(get_simulation_setting "table[-_]extension")
     # if we have all 3 numbers do this checks
     tabl=$(csg_calc "$rlist" + "$tabext")
     [[ -n $tablend  ]] &&  csg_calc "$tablend" "<" "$tabl" && \
@@ -126,15 +127,19 @@ else
   scale="${input}"
 fi
 
+if [[ $tabtype = "dihedral" ]]; then
+  csg_resample_opts=( "--boundaries" "periodic")
+fi
+
 #keep the grid for now, so that extrapolate can calculate the right mean
 smooth="$(critical mktemp ${trunc}.pot.smooth.XXXXX)"
-critical csg_resample --in ${scale} --out "$smooth" --grid "${zero}:${step}:${tablend}"
+critical csg_resample --in "${scale}" --out "$smooth" --grid "${zero}:${step}:${tablend}" "${csg_resample_opts[@]}"
 
 extrapol="$(critical mktemp ${trunc}.pot.extrapol.XXXXX)"
 do_external potential extrapolate ${clean:+--clean} --type "$tabtype" "${smooth}" "${extrapol}"
 
 interpol="$(critical mktemp ${trunc}.pot.interpol.XXXXX)"
-critical csg_resample --in "${extrapol}" --out "$interpol" --grid "${zero}:${gromacs_bins}:${tablend}" --comment "$comment"
+critical csg_resample --in "${extrapol}" --out "$interpol" --grid "${zero}:${gromacs_bins}:${tablend}" "${csg_resample_opts[@]}" --comment "$comment"
 
 if [[ $do_shift = "yes" ]]; then
   tshift="$(critical mktemp ${trunc}.pot.shift.XXXXX)"
@@ -146,5 +151,6 @@ fi
 potmax="$(csg_get_property --allow-empty cg.inverse.gromacs.pot_max)"
 do_external convert_potential xvg ${potmax:+--max} ${potmax} --type "${xvgtype}" "${tshift}" "${output}"
 if [[ $clean ]]; then
-  rm -f "${smooth}" "${interpol}" "${extrapol}" "${tshift}" "${scale}"
+  rm -f "${smooth}" "${interpol}" "${extrapol}" "${tshift}"
+  [[ ${input} = ${scale} ]] || rm -f "${scale}"
 fi
