@@ -26,20 +26,20 @@ EOF
    exit 0
 fi
 
-solver=$(csg_get_property cg.inverse.imc.solver)
 sim_prog="$(csg_get_property cg.inverse.program)"
 do_external imc_stat $sim_prog
 
+default_reg=$(csg_get_property cg.inverse.imc.default_reg)
+is_num "${default_reg}" || die "${0##*/}: value of cg.inverse.imc.default_reg should be a number"
+
 imc_groups=$(csg_get_interaction_property --all inverse.imc.group)
 imc_groups=$(remove_duplicate $imc_groups)
 [[ -z ${imc_groups} ]] && die "${0##*/}: No imc groups defined"
-reg="$(csg_get_interaction_property --all inverse.imc.reg)"
 for group in $imc_groups; do
-  # currently this is a hack! need to create combined array
-  msg "solving linear equations for imc group '$group'"
-  critical csg_imcrepack --in ${group} --out ${group}.packed
-  do_external imcsolver $solver  ${group}.packed ${group}.packed.sol $reg
-  critical csg_imcrepack --in ${group}.packed --unpack ${group}.packed.sol
+  reg="$(csg_get_property cg.inverse.imc.${group}.reg ${default_reg})" #filter me away
+  is_num "${reg}" || die "${0##*/}: value of cg.inverse.imc.${group}.reg should be a number"
+  msg "solving linear equations for imc group '$group' (regularization ${reg})"
+  critical csg_imc_solve --imcfile "${group}.imc" --gmcfile "${group}.gmc" --idxfile "${group}.idx" --regularization "${reg}"
 done
 
-for_all "non-bonded bonded" do_external imc purify
+for_all "non-bonded bonded" do_external update imc_single
