@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,11 +15,16 @@
  *
  */
 
+// Standard includes
 #include <fstream>
-#include <votca/csg/cgengine.h>
-#include <votca/csg/version.h>
+
+// VOTCA includes
 #include <votca/tools/tokenizer.h>
 
+// Local VOTCA includes
+#include "votca/csg/cgengine.h"
+#include "votca/csg/version.h"
+
 namespace votca {
 namespace csg {
 
