@@ -15,14 +15,23 @@
  *
  */
 
-#include "lammpsdatareader.h"
-#include <boost/algorithm/string.hpp>
+// Standard includes
 #include <vector>
-#include <votca/csg/topology.h>
+
+// VOTCA includes
 #include <votca/tools/elements.h>
 #include <votca/tools/floatingpointcomparison.h>
 #include <votca/tools/getline.h>
 
+// Third party includes
+#include <boost/algorithm/string.hpp>
+
+// Local VOTCA includes
+#include "votca/csg/topology.h"
+
+// Local private VOTCA includes
+#include "lammpsdatareader.h"
+
 namespace votca {
 namespace csg {
 using namespace std;
@@ -243,8 +252,8 @@ bool LAMMPSDataReader::MatchFourFieldLabels_(vector<string> fields,
 
 void LAMMPSDataReader::InitializeAtomAndBeadTypes_() {
   if (!data_.count("Masses")) {
-    string err = "Masses must first be parsed before the atoms can be read.";
-    throw runtime_error(err);
+    throw runtime_error(
+        "Masses must first be parsed before the atoms can be read.");
   }
 
   Index index = 0;
@@ -465,10 +474,9 @@ void LAMMPSDataReader::ReadAtoms_(Topology &top) {
       }
 
       if (atomtypes_.count(atomTypeId) == 0) {
-        string err =
+        throw runtime_error(
             "Unrecognized atomTypeId, the atomtypes map "
-            "may be uninitialized";
-        throw runtime_error(err);
+            "may be uninitialized");
       }
 
       string bead_type_name = atomtypes_[atomTypeId];
@@ -480,14 +488,14 @@ void LAMMPSDataReader::ReadAtoms_(Topology &top) {
                          residue_index, mass, charge);
 
       mol->AddBead(b, bead_type_name);
-      b->setMolecule(mol);
+      b->setMoleculeId(mol->getId());
 
     } else {
       b = top.getBead(atomIndex - startingIndex);
     }
 
     Eigen::Vector3d xyz_pos(x, y, z);
-    b->setPos(xyz_pos);
+    b->setPos(xyz_pos * tools::conv::ang2nm);
   }
 
   if (top.BeadCount() != numberOf_["atoms"]) {
@@ -533,7 +541,7 @@ void LAMMPSDataReader::ReadBonds_(Topology &top) {
       ic->setGroup("BONDS");
       ic->setIndex(bondId);
       auto b = top.getBead(atom1Index);
-      auto mi = b->getMolecule();
+      auto mi = top.getMolecule(b->getMoleculeId());
       ic->setMolecule(atomIdToMoleculeId_[atom1Index]);
       top.AddBondedInteraction(ic);
       mi->AddInteraction(ic);
@@ -591,7 +599,7 @@ void LAMMPSDataReader::ReadAngles_(Topology &top) {
       ic->setGroup("ANGLES");
       ic->setIndex(angleId);
       auto b = top.getBead(atom1Index);
-      auto mi = b->getMolecule();
+      auto mi = top.getMolecule(b->getMoleculeId());
       ic->setMolecule(atomIdToMoleculeId_[atom1Index]);
       top.AddBondedInteraction(ic);
       mi->AddInteraction(ic);
@@ -662,7 +670,7 @@ void LAMMPSDataReader::ReadDihedrals_(Topology &top) {
       ic->setGroup("DIHEDRALS");
       ic->setIndex(dihedralId);
       auto b = top.getBead(atom1Index);
-      auto mi = b->getMolecule();
+      auto mi = top.getMolecule(b->getMoleculeId());
       ic->setMolecule(atomIdToMoleculeId_[atom1Index]);
       top.AddBondedInteraction(ic);
       mi->AddInteraction(ic);
