@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,10 +15,15 @@
  *
  */
 
-#include <boost/format.hpp>
-#include <stdio.h>
+// Standard includes
+#include <cstdio>
 #include <string>
-#include <votca/csg/pdbwriter.h>
+
+// Third party includes
+#include <boost/format.hpp>
+
+// Local VOTCA includes
+#include "votca/csg/pdbwriter.h"
 
 namespace votca {
 namespace csg {
