@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,18 +15,25 @@
  *
  */
 
-#include <boost/lexical_cast.hpp>
+// Standard includes
 #include <cassert>
 #include <regex>
 #include <stdexcept>
 #include <unordered_set>
-#include <votca/csg/boundarycondition.h>
-#include <votca/csg/interaction.h>
-#include <votca/csg/molecule.h>
-#include <votca/csg/openbox.h>
-#include <votca/csg/topology.h>
+
+// Third party includes
+#include <boost/lexical_cast.hpp>
+
+// VOTCA includes
 #include <votca/tools/rangeparser.h>
 
+// Local VOTCA includes
+#include "votca/csg/boundarycondition.h"
+#include "votca/csg/interaction.h"
+#include "votca/csg/molecule.h"
+#include "votca/csg/openbox.h"
+#include "votca/csg/topology.h"
+
 namespace votca {
 namespace csg {
 
@@ -336,24 +343,7 @@ BoundaryCondition::eBoxtype Topology::autoDetectBoxType(
 }
 
 double Topology::ShortestBoxSize() const {
-  Eigen::Vector3d box_a = getBox().col(0);
-  Eigen::Vector3d box_b = getBox().col(1);
-  Eigen::Vector3d box_c = getBox().col(2);
-
-  // create plane normals
-  Eigen::Vector3d norm_a = box_b.cross(box_c);
-  Eigen::Vector3d norm_b = box_c.cross(box_a);
-  Eigen::Vector3d norm_c = box_a.cross(box_b);
-
-  norm_a.normalize();
-  norm_b.normalize();
-  norm_c.normalize();
-
-  double la = box_a.dot(norm_a);
-  double lb = box_b.dot(norm_b);
-  double lc = box_c.dot(norm_c);
-
-  return std::min(la, std::min(lb, lc));
+  return _bc->getShortestBoxDimension();
 }
 
 }  // namespace csg
