@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2019 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2020 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,11 +15,11 @@
  *
  */
 
-#ifndef _VOTCA_CSG_FMATCH_H
-#define _VOTCA_CSG_FMATCH_H
+#ifndef VOTCA_CSG_CSG_FMATCH_H
+#define VOTCA_CSG_CSG_FMATCH_H
 
-#include <votca/csg/csgapplication.h>
-#include <votca/csg/trajectoryreader.h>
+#include "../../include/votca/csg/csgapplication.h"
+#include "../../include/votca/csg/trajectoryreader.h"
 #include <votca/tools/cubicspline.h>
 #include <votca/tools/property.h>
 
@@ -65,7 +65,7 @@ class CGForceMatching : public CsgApplication {
   /// parameters
   struct SplineInfo {
     /// \brief constructor
-    SplineInfo(votca::Index index, bool bonded, votca::Index matr_pos,
+    SplineInfo(votca::Index index, bool bonded_, votca::Index matr_pos_,
                votca::tools::Property *options);
     /// \brief number of spline functions
     votca::Index num_splinefun;
@@ -197,7 +197,7 @@ class CGForceMatching : public CsgApplication {
   void OpenForcesTrajectory();
 
   Topology _top_force;
-  TrajectoryReader *_trjreader_force;
+  std::unique_ptr<TrajectoryReader> _trjreader_force;
 };
 
-#endif /* _VOTCA_CSG_FMATCH_H */
+#endif  // VOTCA_CSG_CSG_FMATCH_H
